@@ -2,8 +2,10 @@
 
 # flake8: noqa
 from .core import ChildColAssigner, ColAccessor, ColAssigner
+from .dag_from_ast import get_dag
+from .experiment import experiment, measure_effect
 from .meta_base import get_all_cols, get_att_value
 from .type_hinting import Col
 from .util import camel_to_snake
 
-__version__ = "0.3.1"
+__version__ = "0.4.0"
